---
grand_parent: PIC32CZ Reference Applications
parent: PIC32CZ CA90 Curiosity Ultra Development Board
title: Getting Started with Drivers
nav_order: 3
---

<img src = "images/microchip_logo.png">
<img src = "images/microchip_mplab_harmony_logo_small.png">

# Getting Started Application using Harmony v3 Drivers on PIC32CZ CA90 Curiosity Ultra Development Board using FreeRTOS
<h2 align="center"> <a href="https://github.com/Microchip-MPLAB-Harmony/reference_apps_pic32cz/releases/latest/download/pic32cz_ca90_cult_getting_started_freertos.zip" > Download </a> </h2>

-----
## Description:

> The application reads the current room temperature from the temperature sensor on the I/O1 Xplained Pro Extension Kit. The temperature reading is displayed on a serial console periodically every second. Further, the application writes the temperature readings to EEPROM. When a character is entered on the console, the last five written temperature values are read from the EEPROM and displayed on the console. Also, an LED (LED0) on the PIC32CZ CA90 Curiosity Ultra Development Board is toggled every time the temperature is displayed on the serial console.


## Modules/Technology Used:
- Peripheral Modules  
	- PORT
	- Clock
	- EVSYS
	- SERCOM0
	- SERCOM1
	- TCC0
	- DMA
	- NVIC
- Drivers
	- USART
	- I2C
- System Services
	- Time
- Third Party Libraries
	- FreeRTOS

The MCC Harmony project graph would look like this:
	
  <img src = "images/project_graph.png" width="700" height="500" align="middle">	

## Hardware Used:

- [PIC32CZ CA90 Curiosity Ultra Development Board](https://www.microchip.com/en-us/development-tool/ev16w43a)
- [I/O1 Xplained Pro Extension Kit](https://www.microchip.com/en-us/development-tool/ATIO1-XPRO)

## Software/Tools Used:
<span style="color:blue"> This project has been verified to work with the following versions of software tools:</span>

- [MPLAB X IDE](https://www.microchip.com/en-us/tools-resources/develop/mplab-x-ide) v6.20
- [MPLAB Code Configurator Plugin](https://www.microchip.com/en-us/tools-resources/configure/mplab-code-configurator)  v5.5.1
- [MPLAB XC32 Compiler](https://www.microchip.com/en-us/tools-resources/develop/mplab-xc-compilers) v4.45
- [csp](https://github.com/Microchip-MPLAB-Harmony/csp) v3.20.0
- [core](https://github.com/Microchip-MPLAB-Harmony/core) v3.14.0
- CMSIS_5 v5.9.0
- PIC32CZ-CA90_DFP v1.5.162

Refer [Project Manifest](./firmware/src/config/pic32cz_ca90_cult/harmony-manifest-success.yml) present in harmony-manifest-success.yml under the project folder *pic32cz_ca90_cult_getting_started_freertos/firmware/src/config/pic32cz_ca90_cult*  
- Refer the [Release Notes](../../../../../release_notes.md#development-tools) to know the **MPLAB X IDE** and **MCC** Plugin version. Alternatively, [Click Here](https://github.com/Microchip-MPLAB-Harmony/reference_apps/blob/master/release_notes.md#development-tools).

<span style="color:blue"> Because Microchip regularly update tools, occasionally issue(s) could be discovered while using the newer versions of the tools. If the project doesn’t seem to work and version incompatibility is suspected, It is recommended to double-check and use the same versions that the project was tested with. </span> To download original version of MPLAB Harmony v3 packages, refer to document [How to Use the MPLAB Harmony v3 Project Manifest Feature](https://ww1.microchip.com/downloads/en/DeviceDoc/How-to-Use-the-MPLAB-Harmony-v3-Project-Manifest-Feature-DS90003305.pdf)

## Setup:
- Verify that the I/O1 Xplained Pro Extension Kit (temperature sensor) is connected to Extension Header 1 (EXT1) on the PIC32CZ CA90 Curiosity Ultra Development board.
- Connect the Type-A male to Micro-B USB cable to Micro-B DEBUG USB port (J200) to program and debug the PIC32CZ CA90 Curiosity Ultra Development board and connect to a external power supply (6.5V-14V) to power-up the board.  

  <img src = "images/pic32cz_ca90_cult.png" width="670" height="570" align="middle">
  

## Programming hex file:
The pre-built hex file can be programmed by following the below steps.  

### Steps to program the hex file
- Open MPLAB X IDE
- Close all existing projects in IDE, if any project is opened.
- Go to File -> Import -> Hex/ELF File
- In the "Import Image File" window, Step 1 - Create Prebuilt Project, Click the "Browse" button to select the prebuilt hex file
- Select Device has "PIC32CZ8110CA90208"
- Ensure the proper tool is selected under "Hardware Tool"
- Click on Next button
- In the "Import Image File" window, Step 2 - Select Project Name and Folder, select appropriate project name and folder
- Click on Finish button
- In MPLAB X IDE, click on "Make and Program Device" Button. The device gets programmed in sometime
- Follow the steps in "Running the Demo" section below


## Programming/Debugging Application Project:
- Open the project (pic32cz_ca90_cult_getting_started_freertos/firmware/pic32cz_ca90_cult.X) in MPLAB X IDE
- Ensure "PIC32CZ CA90 Curiosity Ultra" is selected as hardware tool to program/debug the application
- Build the code and program the device by clicking on the "make and program" button in MPLAB X IDE tool bar
- Follow the steps in "Running the Demo" section below.

## Running the Demo:
- Open the Tera Term terminal application on your PC (from the Windows® Start menu by pressing the Start button)
- Change the baud rate to 115200
- You should see the temperature values (in °F) being displayed on the terminal every 500 milliseconds, as shown below  

  <img src = "images/result1.png" width="425" height="235" align="middle">  
- Also, notice the LED0 blinking at 1 second rate
- Press any character on the terminal to display the last five values written to the EEPROM  
<img src = "images/eeprom_values_display.png" width="600" height="285" align="middle">  
- You may vary the temperature by placing your finger on the temperature sensor (for a few seconds)  

  <img src = "images/temp_sensor_placement.png" width="425" height="370" align="middle">  

## Comments:
- Reference Training Module: [Getting Started with MPLAB® Harmony v3 Drivers on SAM E70/S70/V70/V71 MCUs Using FreeRTOS™](https://developerhelp.microchip.com/xwiki/bin/view/software-tools/harmony/same70-getting-started-tm-drivers-freertos/)
- This application demo builds and works out of box by following the instructions above in "Running the Demo" section. If you need to enhance/customize this application demo, you need to use the MPLAB Harmony v3 Software framework. Refer links below to setup and build your applications using MPLAB Harmony.
	- [How to Setup MPLAB Harmony v3 Software Development Framework](https://ww1.microchip.com/downloads/aemDocuments/documents/MCU32/ProductDocuments/SupportingCollateral/How-to-Setup-MPLAB-Harmony-v3-Software-Development-Framework-DS90003232.pdf)
	- [How to Build an Application by Adding a New PLIB, Driver, or Middleware to an Existing MPLAB Harmony v3 Project](https://ww1.microchip.com/downloads/aemDocuments/documents/MCU32/ProductDocuments/SupportingCollateral/How-to-Build-an-Application-by-Adding-a-New-PLIB-Driver-or-Middleware-to-an-Existing-MPLAB-Harmony-v3-Project-DS90003253.pdf)	
	- [Video - How to Set up the Tools Required to Get Started with MPLAB® Harmony v3 and MCC](https://www.youtube.com/watch?v=0rNFSlsVwVw)	
	- [Create a new MPLAB Harmony v3 project using MCC](https://developerhelp.microchip.com/xwiki/bin/view/software-tools/harmony/getting-started-training-module-using-mcc/)
	- [Update and Configure an Existing MHC-based MPLAB Harmony v3 Project to MCC-based Project](https://developerhelp.microchip.com/xwiki/bin/view/software-tools/harmony/update-and-configure-existing-mhc-proj-to-mcc-proj/)

## Revision:
- v1.7.0 - Released demo application